#VSM

[![Build Status](https://img.shields.io/travis/inpho/vsm.svg?label=UNIX+build)](https://travis-ci.org/inpho/vsm)
[![Appveyor](https://img.shields.io/appveyor/ci/JaimieMurdock/vsm.svg?label=Windows+build)](https://ci.appveyor.com/project/JaimieMurdock/vsm)
[![Coveralls](https://img.shields.io/coveralls/inpho/vsm.svg)](https://coveralls.io/r/inpho/vsm)
[![GitHub license](https://img.shields.io/github/license/mashape/apistatus.svg)](https://github.com/inpho/vsm/blob/master/LICENSE.txt)
[![PyPI](https://img.shields.io/pypi/v/vsm.svg)](https://pypi.python.org/pypi/vsm)

**Note:** More than likely, you are looking for the [InPhO Topic Explorer](http://github.com/inpho/topic-explorer). This library is for the machine learning implementations underlying the Topic Explorer and is updated much slower than the user interfaces. If you are using the Topic Explorer, please file issues there and the developers will triage appropriately.

Vector Space Model Framework developed for the 
[InPhO Project](https://inpho.cogs.indiana.edu/).

Documentation can be found in the module and [here](http://inpho.github.io/vsm/).

##Installation

```
git clone git@github.com:inpho/vsm.git
cd vsm
pip install -r requirements.txt -e .
```
